# Managing sphinx translations using launchbuttons

use a launch button (dropdown) to manage different translations of a jupyter-book/sphinx-book.



TODO: 
 - add error handling
 - add documentation
